@@ -3,6 +3,7 @@
 from __future__ import unicode_literals
 from .. import Provider as CompanyProvider
 
+
 class Provider(CompanyProvider):
     formats = (
         '{{company_prefix}} «{{last_name}}»',
@@ -16,6 +17,5 @@ class Provider(CompanyProvider):
         'РАО', 'АО', 'ИП', 'НПО',
     )
 
-    @classmethod
-    def company_prefix(cls):
-        return cls.random_element(cls.company_prefixes)
+    def company_prefix(self):
+        return self.random_element(self.company_prefixes)
